
var _Debug = false; 

var _NoError = 0;
var _GeneralException = 101;
var _ServerBusy = 102;
var _InvalidArgumentError = 201;
var _ElementCannotHaveChildren = 202;
var _ElementIsNotAnArray = 203;
var _NotInitialized = 301;
var _NotImplementedError = 401;
var _InvalidSetValue = 402;
var _ElementIsReadOnly = 403;
var _ElementIsWriteOnly = 404;
var _IncorrectDataType = 405;


var apiHandle = null;
var API = null;
var findAPITries = 0;


function doLMSInitialize() {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSInitialize was not successful.");
        return "false";
    }
	var data = api.cmi.toJSON();
    if (data.suspend_data !== "") {
        glhp.DataLocal.Slide = JSON.parse(data.suspend_data);   
    }
    var result = api.LMSInitialize("");

    if (result.toString() != "true") {
        var err = ErrorHandler();
    }

    return result.toString();
}

function doLMSFinish() {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSFinish was not successful.");
        return "false";
    } else {

        var result = api.LMSFinish("");
        if (result.toString() != "true") {
            var err = ErrorHandler();
        }

    }

    return result.toString();
}

function doLMSGetValue(name) {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSGetValue was not successful.");
        return "";
    } else {
        var value = api.LMSGetValue(name);
        var errCode = api.LMSGetLastError().toString();
        if (errCode != _NoError) {
            var errDescription = api.LMSGetErrorString(errCode);
            alert("LMSGetValue(" + name + ") failed. \n" + errDescription);
            return "";
        } else {

            return value.toString();
        }
    }
}

function doLMSSetValue(name, value) {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSSetValue was not successful.");
        return;
    } else {
        var result = api.LMSSetValue(name, value);
        if (result.toString() != "true") {
            var err = ErrorHandler();
        }
    }

    return;
}

function doLMSCommit() {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSCommit was not successful.");
        return "false";
    } else {
        var result = api.LMSCommit("");
        if (result != "true") {
            var err = ErrorHandler();
        }
    }

    return result.toString();
}

function doLMSGetLastError() {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSGetLastError was not successful.");
        return _GeneralError;
    }

    return api.LMSGetLastError().toString();
}

function doLMSGetErrorString(errorCode) {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSGetErrorString was not successful.");
    }

    return api.LMSGetErrorString(errorCode).toString();
}

function doLMSGetDiagnostic(errorCode) {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSGetDiagnostic was not successful.");
    }

    return api.LMSGetDiagnostic(errorCode).toString();
}

function LMSIsInitialized() {

    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nLMSIsInitialized() failed.");
        return false;
    } else {
        var value = api.LMSGetValue("cmi.core.student_name");
        var errCode = api.LMSGetLastError().toString();
        if (errCode == _NotInitialized) {
            return false;
        } else {
            return true;
        }
    }
}

function ErrorHandler() {
    var api = getAPIHandle();
    if (api == null) {
        alert("Unable to locate the LMS's API Implementation.\nCannot determine LMS error code.");
        return;
    }

    var errCode = api.LMSGetLastError().toString();
    if (errCode != _NoError) {
        var errDescription = api.LMSGetErrorString(errCode);

        if (_Debug == true) {
            errDescription += "\n";
            errDescription += api.LMSGetDiagnostic(null);
        }

        alert(errDescription);
    }

    return errCode;
}

function getAPIHandle() {
    if (apiHandle == null) {
        apiHandle = getAPI();
    }

    return apiHandle;
}


function findAPI(win) {
    while ((win.API == null) && (win.parent != null) && (win.parent != win)) {
        findAPITries++;
        if (findAPITries > 7) {
            alert("Error finding API -- too deeply nested.");
            return null;
        }

        win = win.parent;

    }
    return win.API;
}



function getAPI() {
    var theAPI = findAPI(window);
    if ((theAPI == null) && (window.opener != null) && (typeof (window.opener) != "undefined")) {
        theAPI = findAPI(window.opener);
    }
    if (theAPI == null) {
        alert("Unable to find an API adapter");
    }
    return theAPI
}
var initWithScorm = false;
var ScormEnum = {
    Name: {
        ScoreMin: 'cmi.core.score.min', 
        ScoreMax: 'cmi.core.score.max', 
        TotalTimeLMS: 'cmi.total_time', 
        CoreExit: "cmi.core.exit",
        ScoreRaw: 'cmi.core.score.raw',
        Status: 'cmi.core.lesson_status',
        SesstionTime: 'cmi.core.session_time',
        SuspendData: 'cmi.suspend_data',
		Scale:	'cmi.score.scaled' 
    }
}
var getNameScorm = function (index,name) {
    switch (name) {
        case "StudentRespone":
            return 'cmi.interactions.' + index + '.student_response';
        case "CorrectRespone":
            return 'cmi.interactions.' + index + '.correct_responses.0.pattern';
        case "Result":
            return 'cmi.interactions.' + index + '.result';
        case "CurrentTime":
            return 'cmi.interactions.' + index + '.time';
        case "Id":
            return 'cmi.interactions.' + index + '.id';
        case "ObjectivesId":
            return 'cmi.interactions.' + index + '.objectives.0.id';
		case "Type":
			return 'cmi.interactions.'+index+'.type';
		case "Weight":
			return 'cmi.interactions.'+index+'.weighting';
		case 'Latency': 
			return 'cmi.interactions.'+index+'.latency'; 
        default:
            break;
    }
}
var ScormModule = function () {
    return {
        StartLecture: function () {
            var result = doLMSInitialize();
            initWithScorm = result;
            this.SetValue(ScormEnum.Name.CoreExit, "suspend");
        },
        EndLecture: function () {
            doLMSFinish();
        },
        Commit: function () {
            doLMSCommit();
        },
        SetValue: function (name, value) {
            doLMSSetValue(name, value);
        },
        GetValue: function (name) {
            return doLMSGetValue(name);
        }
    }
}();
ScormModule.StartLecture();
